==> apache-servicecomb-java-chassis-distribution-2.8.16-src.zip: apache-servicecomb-java-chassis-distribution-2.8.16-src/swagger/swagger-invocation/invocation-jaxrs/src/main/java/org/apache/servicecomb/swagger/invocation/jaxrs/response/JaxrsConsumerResponseMapper.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.servicecomb.swagger.invocation.jaxrs.response;

import java.util.Map.Entry;

import javax.ws.rs.core.Response.ResponseBuilder;

import org.apache.servicecomb.swagger.invocation.Response;
import org.apache.servicecomb.swagger.invocation.response.consumer.ConsumerResponseMapper;

import io.vertx.core.MultiMap;

public class JaxrsConsumerResponseMapper implements ConsumerResponseMapper {
  @Override
  public Object mapResponse(Response response) {
    ResponseBuilder responseBuilder =
        javax.ws.rs.core.Response.status(response.getStatus()).entity(response.getResult());

    MultiMap headers = response.getHeaders();
    if (headers == null) {
      return responseBuilder.build();
    }

    for (Entry<String, String> entry : headers.entries()) {
      responseBuilder.header(entry.getKey(), entry.getValue());
    }

    return responseBuilder.build();
  }
}

==> apache-servicecomb-java-chassis-distribution-3.2.2-src.zip: apache-servicecomb-java-chassis-distribution-3.2.2-src/swagger/swagger-invocation/invocation-jaxrs/src/main/java/org/apache/servicecomb/swagger/invocation/jaxrs/response/JaxrsConsumerResponseMapper.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.servicecomb.swagger.invocation.jaxrs.response;

import java.util.Map.Entry;

import jakarta.ws.rs.core.Response.ResponseBuilder;

import org.apache.servicecomb.swagger.invocation.Response;
import org.apache.servicecomb.swagger.invocation.response.consumer.ConsumerResponseMapper;

import io.vertx.core.MultiMap;

public class JaxrsConsumerResponseMapper implements ConsumerResponseMapper {
  @Override
  public Object mapResponse(Response response) {
    ResponseBuilder responseBuilder =
        jakarta.ws.rs.core.Response.status(response.getStatus()).entity(response.getResult());

    MultiMap headers = response.getHeaders();
    if (headers == null) {
      return responseBuilder.build();
    }

    for (Entry<String, String> entry : headers.entries()) {
      responseBuilder.header(entry.getKey(), entry.getValue());
    }

    return responseBuilder.build();
  }
}
